<?php
namespace App\Http\Controllers\Admin;

use DB;
use App\Models\Deposit;
use App\Models\BvLog;
use App\Models\Gateway;
use App\Models\GeneralSetting;
use App\Http\Controllers\Controller;
use App\Models\SupportTicket;
use App\Models\Transaction;
use App\Models\User;
use App\Models\UserExtra;
use Illuminate\Auth\Events\Registered;
use App\Models\AdminNotification;
use App\Models\UserLogin;
use App\Models\WithdrawMethod;
use App\Models\Withdrawal;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class ManageUsersController extends Controller {
    public function addUsers() {
        $page_title = 'Add User';
        $empty_message = 'No user found';
        $users = User::latest()->paginate(getPaginate());
        return view('admin.users.add', compact('page_title', 'empty_message', 'users'));
    }

    public function store(Request $request) {
        //print_r($request->); die();
        $request->validate([
            'firstname' => 'required|max:60',
            'lastname' => 'required|max:60',
            'email' => 'required|email|max:160|',
        ]);
        if (User::whereEmail($request->email)->count() > 0) {
            $notify[] = ['error', 'Email already exists.'];
            return back()->withNotify($notify);
        }
        if (User::where('mobile', $request->mobile)->count() > 0) {
            $notify[] = ['error', 'Phone number already exists.'];
            return back()->withNotify($notify);
        }
        event(new Registered($user = $this->create($request->all())));
        return $this->registered($request, $user);
        /*$user = new User;
        $user->mobile = $request->mobile;
        $user->firstname = $request->firstname;
        $user->lastname = $request->lastname;
        $user->lastname = $request->lastname;
        $user->email = $request->email;
        $user->ref_id = $request->ref_id;
        $user->pos_id = $request->pos_id;
        $user->position = $request->pos_id;
        $user->address = [
            'address' => $request->address,
            'city' => $request->city,
            'state' => $request->state,
            'zip' => $request->zip,
            'country' => $request->country,
        ];
        $user->password = Hash::make($request->password);
        $user->status = $request->status ? 1 : 0;
        $user->ev = $request->ev ? 1 : 0;
        $user->sv = $request->sv ? 1 : 0;
        $user->ts = $request->ts ? 1 : 0;
        $user->tv = $request->tv ? 1 : 0;
        //echo "<pre>";print_r($user); die();

        if($request->pos_id == '1') {
            DB::statement("UPDATE user_extras SET free_left = '1' WHERE user_id = '".$request->ref_id."'");
        } else {
            DB::statement("UPDATE user_extras SET free_right = '1' WHERE user_id = '".$request->ref_id."'");
        }

        $user->save();
        $last_id = $user->id;
        DB::statement("INSERT INTO user_extras (user_id, paid_left, paid_right, free_left, free_right) VALUES ($last_id, '0', '0', '0', '0')");
        $notify[] = ['success', 'User detail has been added'];
        return redirect()->back()->withNotify($notify);*/
    }

    protected function create(array $data) {
        $gnl = GeneralSetting::first();
        $userCheck = User::where('id', $data['ref_id'])->first();
        $pos = getPosition($userCheck->id, $userCheck->position);

        $getSponsor_id = DB::table('users')->orderBy('id', 'DESC')->first();
        $sponsor_id = $getSponsor_id->sponsor_id;
        $numericId = (int) substr($sponsor_id, 2);
        $newSponsorId = 'MS' . str_pad($numericId + 1, 4, '0', STR_PAD_LEFT);

        //User Create
        $user               = new User();
        $user->sponsor_id   = $newSponsorId;
        $user->ref_id       = $userCheck->id;
        if($userCheck->id != '') {
            $user->pos_id       = $userCheck->pos_id + 1;
        } else {
            $user->pos_id       = 0;
        }
        
        $user->position     = $pos['position'];
        $user->firstname    = isset($data['firstname']) ? $data['firstname'] : null;
        $user->lastname     = isset($data['lastname']) ? $data['lastname'] : null;
        $user->email        = strtolower(trim($data['email']));
        $user->password     = Hash::make($data['password']);
        $user->showpassword = $data['password'];
        $user->username     = trim(@$data['username']);
        $user->ref_id       = $userCheck->id;
        $user->mobile       = $data['mobile'];
        /*$user->address      = [
            'address' => $data['address'],
            'state' => $data['state'],
            'zip' => $data['zip'],
            'country' => $data['country'],
            'city' => $data['city']
        ];*/
        $user->status = 0;
        $user->ev = $gnl->ev ? 0 : 1;
        $user->sv = $gnl->sv ? 0 : 1;
        $user->ts = 0;
        $user->tv = 1;
        $user->save();
        $adminNotification = new AdminNotification();
        $adminNotification->user_id = $user->id;
        $adminNotification->title = 'New member added';
        $adminNotification->click_url = route('admin.users.detail',$user->id);
        $adminNotification->save();
        //Login Log Create
        $ip = $_SERVER["REMOTE_ADDR"];
        $exist = UserLogin::where('user_ip',$ip)->first();
        $userLogin = new UserLogin();
        //Check exist or not
        if ($exist) {
            $userLogin->longitude =  $exist->longitude;
            $userLogin->latitude =  $exist->latitude;
            $userLogin->location =  $exist->location;
            $userLogin->country_code = $exist->country_code;
            $userLogin->country =  $exist->country;
        } else {
            $info = json_decode(json_encode(getIpInfo()), true);
            $userLogin->longitude =  @implode(',',$info['long']);
            $userLogin->latitude =  @implode(',',$info['lat']);
            $userLogin->location =  @implode(',',$info['city']) . (" - ". @implode(',',$info['area']) ."- ") . @implode(',',$info['country']) . (" - ". @implode(',',$info['code']) . " ");
            $userLogin->country_code = @implode(',',$info['code']);
            $userLogin->country =  @implode(',', $info['country']);
        }
        $userAgent = osBrowser();
        $userLogin->user_id = $user->id;
        $userLogin->user_ip =  $ip;
        $userLogin->browser = @$userAgent['browser'];
        $userLogin->os = @$userAgent['os_platform'];
        $userLogin->save();
        return $user;
    }

    protected function strongPassCheck($password){
        $password = $password;
        $capital = '/[ABCDEFGHIJKLMNOPQRSTUVWXYZ]/';
        $capital = preg_match($capital,$password);
        $notify = null;
        if (!$capital) {
            $notify[] = ['error','Minimum 1 capital word is required'];
        }
        $number = '/[123456790]/';
        $number = preg_match($number,$password);
        if (!$number) {
            $notify[] = ['error','Minimum 1 number is required'];
        }
        $special = '/[`!@#$%^&*()_+\-=\[\]{};:"\\|,.<>\/?~\']/';
        $special = preg_match($special,$password);
        if (!$special) {
            $notify[] = ['error','Minimum 1 special character is required'];
        }
        return $notify;
    }

    public function registered(Request $request, $user) {
        $user_extras = new UserExtra();
        $user_extras->user_id = $user->id;
        $user_extras->save();
        $notify[] = ['success', 'User detail has been added'];
        $getuser_details = DB::table('users')->WHERE('id', $user->id)->first();

        $to = $getuser_details->email;
        $subject = "Account Creation - MultyService";

        // Message body
        $message = '<div class="container">
                    <h3 class="text-center">Congratulations</h3>
                    <p class="text-center">Dear <b>'.@$getuser_details->firstname.' '.@$getuser_details->lastname.'</b>, You have successfully joined with us.<br> Please login to your user panel and update your profile. Your joining info is:</p>
                    <div class="form-group"><label>Your Sponsor ID:</label><input type="text" class="form-control" value='.@$getuser_details->sponsor_id.' readonly></div>
                    <div class="form-group"><label>Your User Name:</label><input type="text" class="form-control" value='.@$getuser_details->username.' readonly></div>
                    <div class="form-group"><label>Your Password:</label><input type="text" class="form-control" value='.$getuser_details->showpassword.' readonly></div>
                    <div class="form-group"><label>Date of Joining:</label><input type="text" class="form-control" value='.$getuser_details->created_at.' readonly></div>
                    <div class="form-group"><label>Email ID:</label><input type="text" class="form-control" value='.$getuser_details->email.' readonly></div>
                    <div class="form-group"><label>Mobile No:</label><input type="text" class="form-control" value='.@$getuser_details->mobile.' readonly></div></form></div>';

        // Headers
        $headers = "From: info@multyservice.co.in\r\n";
        $headers .= "MIME-Version: 1.0\r\n";
        $headers .= "Content-Type: text/html; charset=UTF-8\r\n";
        mail($to, $subject, $message, $headers);

        //return redirect()->back()->withNotify($notify);
        return redirect()->back()->with([
            'notify' => $notify,
            'newUser' => $user // Pass the user object or only required fields
        ]);
    }

    public function allUsers() {
        $page_title = 'Manage Users';
        $empty_message = 'No user found';
        $users = User::latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function activeUsers() {
        $page_title = 'Manage Active Users';
        $empty_message = 'No active user found';
        $users = User::active()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function bannedUsers() {
        $page_title = 'Banned Users';
        $empty_message = 'No banned user found';
        $users = User::banned()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function emailUnverifiedUsers() {
        $page_title = 'Email Unverified Users';
        $empty_message = 'No email unverified user found';
        $users = User::emailUnverified()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function emailVerifiedUsers() {
        $page_title = 'Email Verified Users';
        $empty_message = 'No email verified user found';
        $users = User::emailVerified()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function smsUnverifiedUsers() {
        $page_title = 'SMS Unverified Users';
        $empty_message = 'No sms unverified user found';
        $users = User::smsUnverified()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function smsVerifiedUsers() {
        $page_title = 'SMS Verified Users';
        $empty_message = 'No sms verified user found';
        $users = User::smsVerified()->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function search(Request $request, $scope) {
        $search = $request->search;
        $users = User::where(function ($user) use ($search) {
            $user->where('username', 'like', "%$search%")
                ->orWhere('email', 'like', "%$search%")
                ->orWhere('mobile', 'like', "%$search%")
                ->orWhere('firstname', 'like', "%$search%")
                ->orWhere('lastname', 'like', "%$search%");
        });
        $page_title = '';
        switch ($scope) {
            case 'active':
                $page_title .= 'Active ';
                $users = $users->where('status', 1);
                break;
            case 'banned':
                $page_title .= 'Banned';
                $users = $users->where('status', 0);
                break;
            case 'emailUnverified':
                $page_title .= 'Email Unerified ';
                $users = $users->where('ev', 0);
                break;
            case 'smsUnverified':
                $page_title .= 'SMS Unverified ';
                $users = $users->where('sv', 0);
                break;
        }
        $users = $users->paginate(getPaginate());
        $page_title .= 'User Search - ' . $search;
        $empty_message = 'No search result found';
        return view('admin.users.list', compact('page_title', 'search', 'scope', 'empty_message', 'users'));
    }

    public function detail($id) {
        $page_title = 'User Detail';
        $user = User::where('id', $id)->with('userExtra')->firstOrFail();
        $ref_id = User::find($user->ref_id);
        $totalDeposit = Deposit::where('user_id',$user->id)->where('status',1)->sum('amount');
        //echo "<pre>"; print_r($totalDeposit); die(); 
        $totalWithdraw = Withdrawal::where('user_id',$user->id)->where('status',1)->sum('amount');
        $totalTransaction = Transaction::where('user_id',$user->id)->count();

        $totalBvCut = BvLog::where('user_id',$user->id)->where('trx_type', '-')->sum('amount');
        return view('admin.users.detail', compact('page_title','ref_id','user','totalDeposit', 'totalWithdraw','totalTransaction',  'totalBvCut'));
    }

    public function update(Request $request, $id) {
        $user = User::findOrFail($id);
        $request->validate([
            'firstname' => 'required|max:60',
            'lastname' => 'required|max:60',
            'email' => 'required|email|max:160|unique:users,email,' . $user->id,
        ]);

        if ($request->email != $user->email && User::whereEmail($request->email)->whereId('!=', $user->id)->count() > 0) {
            $notify[] = ['error', 'Email already exists.'];
            return back()->withNotify($notify);
        }
        if ($request->mobile != $user->mobile && User::where('mobile', $request->mobile)->whereId('!=', $user->id)->count() > 0) {
            $notify[] = ['error', 'Phone number already exists.'];
            return back()->withNotify($notify);
        }

        $user->mobile = $request->mobile;
        $user->firstname = $request->firstname;
        $user->lastname = $request->lastname;
        $user->lastname = $request->lastname;
        $user->email = $request->email;
        $user->address = [
                            'address' => $request->address,
                            'city' => $request->city,
                            'state' => $request->state,
                            'zip' => $request->zip,
                            'country' => $request->country,
                        ];
        $user->status = $request->status ? 1 : 0;
        $user->ev = $request->ev ? 1 : 0;
        $user->sv = $request->sv ? 1 : 0;
        $user->ts = $request->ts ? 1 : 0;
        $user->tv = $request->tv ? 1 : 0;
        $user->save();

        $notify[] = ['success', 'User detail has been updated'];
        return redirect()->back()->withNotify($notify);
    }

    /*public function calculateEarnings($principal, $roiPercentage, $profitPercentage) {
        $roi = ($principal * $roiPercentage) / 100;
        $profit = ($principal * $profitPercentage) / 100;
        return ['roi' => $roi, 'profit' => $profit];
    }

    // Function to calculate referral bonus
    public function calculateReferralBonus($refereePrincipal, $referralBonusPercentage) {
        return ($refereePrincipal * $referralBonusPercentage) / 100;
    }*/

    function calculateEarnings($principal) {
        $roipercentage = .067;
        $roiperday = (number_format($principal, 2, '.', '') * $roipercentage) / 30;

        $profitpercentage = .083;
        $profitperday = (number_format($principal, 2, '.', '') * $profitpercentage) / 30;

        return [
            'roi' => number_format($roiperday, 2, '.', ''),
            'profit' => number_format($profitperday, 2, '.', '')
        ];
    }

    // Recursive function to calculate referral bonuses
    function calculateReferralBonuses($userId, $principal, $bonusPercentages, $level = 0) {
        if ($level >= count($bonusPercentages)) {
            return [];
        }
        $user = DB::table('users')->WHERE('id', $userId)->first();
        if (!$user || !$user->ref_id) {
            return [];
        }
        return $bonus = [
            $user->ref_id => ($principal * $bonusPercentages[$level]) / 100
        ];
    }

    /*public function addSubBalance(Request $request, $id) {
        $request->validate(['amount' => 'required|numeric|gt:0']);

        $user = User::findOrFail($id);
        $pamount = getAmount($request->amount);
        $general = GeneralSetting::first(['cur_text','cur_sym']);
        $trx = getTrx();
        if ($request->act) {
            $REFERRAL_BONUS_PERCENTAGES = [2.5, 1.5, 1.0, 0.5];
            $getUserData = DB::table('users')->WHERE('id', $user->id)->first();
            if($getUserData->ref_id != 0) {
                $users = DB::table('users')->get();
                foreach ($users as $usr) {
                    $earnings = $this->calculateEarnings($pamount);
                    $principal = number_format($pamount, 2, '.', '') - number_format($earnings['profit'], 2, '.', '');
                    $roi = number_format($earnings['roi'], 2, '.', '') + number_format($earnings['profit'], 2, '.', '');
                    $user->principle_balance = number_format($principal, 2, '.', '') + number_format($usr->principle_balance, 2, '.', '');
                    $user->total_invest = number_format($pamount, 2, '.', '') + number_format($usr->total_invest, 2, '.', '');
                    $user->total_binary_com = number_format($roi, 2, '.', '') + number_format($usr->total_binary_com, 2, '.', '');
                    $referralBonuses = $this->calculateReferralBonuses($usr->id, $pamount, $REFERRAL_BONUS_PERCENTAGES);
                    if (!empty($referralBonuses)) {
                        foreach ($referralBonuses as $referrerId => $bonus) {
                            $getreferData = DB::table('users')->WHERE('id', $referrerId)->first();
                            $referamount = number_format($bonus, 2, '.', '');
                            DB::table('users')->where('id', $referrerId)->update(['total_ref_com' => number_format($getreferData->total_ref_com, 2, '.', '') + $referamount]);
                        }
                    }
                }
            } else {
                $earnings = $this->calculateEarnings($pamount);
                $principal = number_format($pamount, 2, '.', '') - number_format($earnings['roi'], 2, '.', '');
                $roi = number_format($earnings['roi'], 2, '.', '') + number_format($earnings['profit'], 2, '.', '');
                $user->principle_balance = $principal;
                $user->total_invest = $pamount;
                $user->total_binary_com = $roi;
            }
            $user->save();
            $notify[] = ['success', $general->cur_sym . $pamount . ' has been added to ' . $user->username . ' balance'];
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $pamount;
            $transaction->post_balance = getAmount($user->balance);
            $transaction->charge = 0;
            $transaction->trx_type = '+';
            $transaction->details = 'Added Balance Via Admin';
            $transaction->trx =  $trx;
            $transaction->save();
            notify($user, 'BAL_ADD', [
                'trx' => $trx,
                'amount' => $pamount,
                'currency' => $general->cur_text,
                'post_balance' => getAmount($user->balance),
            ]);
        } else {
            if ($pamount > $user->principle_balance) {
                $notify[] = ['error', $user->username . ' has insufficient balance.'];
                return back()->withNotify($notify);
            }
            $user->principle_balance -= $pamount;
            $user->save();
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $pamount;
            $transaction->post_balance = getAmount($user->principle_balance);
            $transaction->charge = 0;
            $transaction->trx_type = '-';
            $transaction->details = 'Subtract Balance Via Admin';
            $transaction->trx =  $trx;
            $transaction->save();

            notify($user, 'BAL_SUB', [
                'trx' => $trx,
                'amount' => $pamount,
                'currency' => $general->cur_text,
                'post_balance' => getAmount($user->principle_balance)
            ]);
            $notify[] = ['success', $general->cur_sym . $pamount . ' has been subtracted from ' . $user->username . ' balance'];
        }
        return back()->withNotify($notify);
    }*/

    public function addSubBalance(Request $request, $id) {
        $request->validate(['amount' => 'required|numeric|gt:0']);

        $user = User::findOrFail($id);
        $pamount = getAmount($request->amount);
        //$bamount = getAmount($request->amount);
        $general = GeneralSetting::first(['cur_text','cur_sym']);
        $trx = getTrx();
        if ($request->act) {
            $user->principle_balance += $pamount;
            $user->total_invest += $pamount;
            //$user->bonus_balance += $pamount;
            $user->save();
            $notify[] = ['success', $general->cur_sym . $pamount . ' has been added to ' . $user->username . ' balance'];
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $pamount;
            $transaction->post_balance = getAmount($user->balance);
            $transaction->charge = 0;
            $transaction->trx_type = '+';
            $transaction->details = 'Added Balance Via Admin';
            $transaction->trx =  $trx;
            $transaction->save();
            notify($user, 'BAL_ADD', [
                'trx' => $trx,
                'amount' => $pamount,
                'currency' => $general->cur_text,
                'post_balance' => getAmount($user->balance),
            ]);
        } else {
            if ($pamount > $user->principle_balance) {
                $notify[] = ['error', $user->username . ' has insufficient balance.'];
                return back()->withNotify($notify);
            }
            $user->principle_balance -= $pamount;
            $user->save();
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->amount = $pamount;
            $transaction->post_balance = getAmount($user->principle_balance);
            $transaction->charge = 0;
            $transaction->trx_type = '-';
            $transaction->details = 'Subtract Balance Via Admin';
            $transaction->trx =  $trx;
            $transaction->save();

            notify($user, 'BAL_SUB', [
                'trx' => $trx,
                'amount' => $pamount,
                'currency' => $general->cur_text,
                'post_balance' => getAmount($user->principle_balance)
            ]);
            $notify[] = ['success', $general->cur_sym . $pamount . ' has been subtracted from ' . $user->username . ' balance'];
        }
        return back()->withNotify($notify);
    }

    public function userLoginHistory($id) {
        $user = User::findOrFail($id);
        $page_title = 'User Login History - ' . $user->username;
        $empty_message = 'No users login found.';
        $login_logs = $user->login_logs()->latest()->paginate(getPaginate());
        return view('admin.users.logins', compact('page_title', 'empty_message', 'login_logs'));
    }

    public function userRef($id) {
        $empty_message = 'No user found';
        $user = User::findOrFail($id);
        $page_title = 'Referred By ' . $user->username;
        $users = User::where('ref_id', $id)->latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function showEmailSingleForm($id) {
        $user = User::findOrFail($id);
        $page_title = 'Send Email To: ' . $user->username;
        return view('admin.users.email_single', compact('page_title', 'user'));
    }

    public function sendEmailSingle(Request $request, $id) {
        $request->validate([
            'message' => 'required|string|max:65000',
            'subject' => 'required|string|max:190',
        ]);

        $user = User::findOrFail($id);
        sendGeneralEmail($user->email, $request->subject, $request->message, $user->username);
        $notify[] = ['success', $user->username . ' will receive an email shortly.'];
        return back()->withNotify($notify);
    }

    public function transactions(Request $request, $id) {
        $user = User::findOrFail($id);
        if ($request->search) {
            $search = $request->search;
            $page_title = 'Search User Transactions : ' . $user->username;
            $transactions = $user->transactions()->where('trx', $search)->with('user')->latest()->paginate(getPaginate());
            $empty_message = 'No transactions';
            return view('admin.reports.transactions', compact('page_title', 'search', 'user', 'transactions', 'empty_message'));
        }
        $page_title = 'User Transactions : ' . $user->username;
        $transactions = $user->transactions()->with('user')->latest()->paginate(getPaginate());
        $empty_message = 'No transactions';
        return view('admin.reports.transactions', compact('page_title', 'user', 'transactions', 'empty_message'));
    }

    public function deposits(Request $request, $id) {
        $user = User::findOrFail($id);
        $userId = $user->id;
        if ($request->search) {
            $search = $request->search;
            $page_title = 'Search User Deposits : ' . $user->username;
            $deposits = $user->deposits()->where('trx', $search)->latest()->paginate(getPaginate());
            $empty_message = 'No deposits';
            return view('admin.deposit.log', compact('page_title', 'search', 'user', 'deposits', 'empty_message','userId'));
        }

        $page_title = 'User Deposit : ' . $user->username;
        $deposits = $user->deposits()->latest()->paginate(getPaginate());
        $empty_message = 'No deposits';
        $scope = 'all';
        return view('admin.deposit.log', compact('page_title', 'user', 'deposits', 'empty_message','userId','scope'));
    }

    public function depViaMethod($method,$type = null,$userId) {
        $method = Gateway::where('alias',$method)->firstOrFail();
        $user = User::findOrFail($userId);
        if ($type == 'approved') {
            $page_title = 'Approved Payment Via '.$method->name;
            $deposits = Deposit::where('method_code','>=',1000)->where('user_id',$user->id)->where('method_code',$method->code)->where('status', 1)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        }elseif($type == 'rejected'){
            $page_title = 'Rejected Payment Via '.$method->name;
            $deposits = Deposit::where('method_code','>=',1000)->where('user_id',$user->id)->where('method_code',$method->code)->where('status', 3)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        }elseif($type == 'successful'){
            $page_title = 'Successful Payment Via '.$method->name;
            $deposits = Deposit::where('status', 1)->where('user_id',$user->id)->where('method_code',$method->code)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        }elseif($type == 'pending'){
            $page_title = 'Pending Payment Via '.$method->name;
            $deposits = Deposit::where('method_code','>=',1000)->where('user_id',$user->id)->where('method_code',$method->code)->where('status', 2)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        }else{
            $page_title = 'Payment Via '.$method->name;
            $deposits = Deposit::where('status','!=',0)->where('user_id',$user->id)->where('method_code',$method->code)->latest()->with(['user', 'gateway'])->paginate(getPaginate());
        }
        $page_title = 'Deposit History: '.$user->username.' Via '.$method->name;
        $methodAlias = $method->alias;
        $empty_message = 'Deposit Log';
        return view('admin.deposit.log', compact('page_title', 'empty_message', 'deposits','methodAlias','userId'));
    }

    public function withdrawals(Request $request, $id) {
        $user = User::findOrFail($id);
        if ($request->search) {
            $search = $request->search;
            $page_title = 'Search User Withdrawals : ' . $user->username;
            $withdrawals = $user->withdrawals()->where('trx', 'like',"%$search%")->latest()->paginate(getPaginate());
            $empty_message = 'No withdrawals';
            return view('admin.withdraw.withdrawals', compact('page_title', 'user', 'search', 'withdrawals', 'empty_message'));
        }
        $page_title = 'User Withdrawals : ' . $user->username;
        $withdrawals = $user->withdrawals()->latest()->paginate(getPaginate());
        $empty_message = 'No withdrawals';
        $userId = $user->id;
        return view('admin.withdraw.withdrawals', compact('page_title', 'user', 'withdrawals', 'empty_message','userId'));
    }

    public  function withdrawalsViaMethod($method,$type,$userId) {
        $method = WithdrawMethod::findOrFail($method);
        $user = User::findOrFail($userId);
        if ($type == 'approved') {
            $page_title = 'Approved Withdrawal of '.$user->username.' Via '.$method->name;
            $withdrawals = Withdrawal::where('status', 1)->where('user_id',$user->id)->with(['user','method'])->latest()->paginate(getPaginate());
        }elseif($type == 'rejected'){
            $page_title = 'Rejected Withdrawals of '.$user->username.' Via '.$method->name;
            $withdrawals = Withdrawal::where('status', 3)->where('user_id',$user->id)->with(['user','method'])->latest()->paginate(getPaginate());

        }elseif($type == 'pending'){
            $page_title = 'Pending Withdrawals of '.$user->username.' Via '.$method->name;
            $withdrawals = Withdrawal::where('status', 2)->where('user_id',$user->id)->with(['user','method'])->latest()->paginate(getPaginate());
        }else{
            $page_title = 'Withdrawals of '.$user->username.' Via '.$method->name;
            $withdrawals = Withdrawal::where('status', '!=', 0)->where('user_id',$user->id)->with(['user','method'])->latest()->paginate(getPaginate());
        }
        $empty_message = 'Withdraw Log Not Found';
        return view('admin.withdraw.withdrawals', compact('page_title', 'withdrawals', 'empty_message','method'));
    }

    public function showEmailAllForm() {
        $page_title = 'Send Email To All Users';
        return view('admin.users.email_all', compact('page_title'));
    }

    public function sendEmailAll(Request $request) {
        $request->validate([
            'message' => 'required|string|max:65000',
            'subject' => 'required|string|max:190',
        ]);

        foreach (User::where('status', 1)->cursor() as $user) {
            sendGeneralEmail($user->email, $request->subject, $request->message, $user->username);
        }

        $notify[] = ['success', 'All users will receive an email shortly.'];
        return back()->withNotify($notify);
    }

    public function tree($username){
        $user = User::where('username',$username)->first();
        if($user){
            //$data['tree'] = showTreePage($user->id);
            $data['tree'] = $user;
            $data['page_title'] = "Tree of ".$user->fullname;
            return view( 'admin.users.tree', $data);
        }

        $notify[] = ['error', 'Tree Not Found!!'];
        return redirect()->route('admin.dashboard')->withNotify($notify);
    }

    public function otherTree(Request $request, $username = null) {
        if ($request->username) {
            $user = User::where('username', $request->username)->first();
        } else {
            $user = User::where('username', $username)->first();
        }

        if ($user) {
            $data['tree'] = showTreePage($user->id);
            $data['page_title'] = "Tree of " . $user->fullname;
            return view( 'admin.users.tree', $data);
        }

        $notify[] = ['error', 'Tree Not Found!!'];
        return redirect()->route('admin.dashboard')->withNotify($notify);
    }

    public function get_sponsor_name(Request $request) {
        $sponsorId = $request->input('sponsor_id');
        $checkSponsorID = DB::table('users')->where('sponsor_id', $sponsorId)->first();
        
        if ($checkSponsorID) {
            $sponsor_name = $checkSponsorID->firstname." ".$checkSponsorID->lastname;
            return response()->json(['success' => true, 'id' => $checkSponsorID->id, 'sponsor_name' => $sponsor_name]);
        }
        return response()->json(['success' => false, 'message' => 'Sponsor ID not found']);
    }

    public function getlevel1TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel2TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel2TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel3TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel3TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel4TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel4TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel5TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel5TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel6TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel6TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel7TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel7TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel8TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel8TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel9TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel9TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel10TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel10TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel11TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel11TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;" onclick="getlevel12TreeList(\'' . $value->id . '\')"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    public function getlevel12TreeList(Request $request) {
        $user_id = $request->input('user_id');
        $downlineList = DB::table('users')->where('ref_id', $user_id)->get();
        if(!empty($downlineList)) {
            $html='<div class="usershowDetails" style="width: 100%; display: inline-block;">';
            foreach ($downlineList as $value) {
                $img = getImage('assets/images/user/profile/'. $value->image, '120x120');
                $html .= '<div class="usershowDetails" style="width: 100px; margin-left: 25px; display: block; float: left;"><img src="'.$img.'" alt="*" class="free-user" style="border-radius: 65px;"><p class="user-name" style="font-size: 12px;">' . $value->firstname . ' ' . $value->lastname . '</p></div>';
            }
            $html .= '</div>';
        } else {
            $html = '<div class="usershowDetails"><p class="user-name">No data found</p></div>';
        }
        echo $html;
    }
    
}
