<?php


namespace App\Http\Controllers;
use App\Models\GeneralSetting;
use App\Models\Transaction;
use App\Models\User;
use App\Models\UserExtra;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

use Illuminate\Support\Facades\Log;

class CronController extends Controller {
    public function cron() {
        $gnl = GeneralSetting::first();
        $gnl->last_cron = Carbon::now()->toDateTimeString();
        $gnl->save();
        if ($gnl->matching_bonus_time == 'daily') {
            $day = Date('H');
            if (strtolower($day) != $gnl->matching_when) {
                return '1';
            }
        }
        if ($gnl->matching_bonus_time == 'weekly') {
            $day = Date('D');
            if (strtolower($day) != $gnl->matching_when) {
                return '2';
            }
        }
        if ($gnl->matching_bonus_time == 'monthly') {
            $day = Date('d');
            if (strtolower($day) != $gnl->matching_when) {
                return '3';
            }
        }
        $gnl->last_paid = Carbon::now()->toDateString();
        $gnl->save();
        $eligibleUsers = UserExtra::where('bv_left', '>=', $gnl->total_bv)->where('bv_right', '>=', $gnl->total_bv)->with('user')->get();
        foreach ($eligibleUsers as $i=>$uex) {
            $user = $uex->user;
            $weak = $uex->bv_left < $uex->bv_right ? $uex->bv_left : $uex->bv_right;
            $weaker = $weak < $gnl->max_bv ? $weak : $gnl->max_bv;
            $bv_price = $gnl->bv_price / $gnl->total_bv;
            $bonus = $weaker * $bv_price;
            // add balance to User
            $user->balance += $bonus;
            $user->save();
            $trx = new Transaction();
            $trx->user_id = $user->id;
            $trx->amount = $bonus;
            $trx->charge = 0;
            $trx->trx_type = '+';
            $trx->post_balance = $user->balance;
            $trx->remark = 'binary_commission';
            $trx->trx = getTrx();
            $trx->details = 'Paid ' . $bonus . ' ' . $gnl->cur_text . ' For ' . $weaker . ' BV.';
            $trx->save();
            $paidbv = $weaker;
            if ($gnl->cary_flash == 0) {
                $bv['setl'] = $uex->bv_left - $paidbv;
                $bv['setr'] = $uex->bv_right - $paidbv;
                $bv['paid'] = $paidbv;
                $bv['lostl'] = 0;
                $bv['lostr'] = 0;
            }
            if ($gnl->cary_flash == 1) {
                $bv['setl'] = $uex->bv_left - $weak;
                $bv['setr'] = $uex->bv_right - $weak;
                $bv['paid'] = $paidbv;
                $bv['lostl'] = $weak - $paidbv;
                $bv['lostr'] = $weak - $paidbv;
            }
            if ($gnl->cary_flash == 2) {
                $bv['setl'] = 0;
                $bv['setr'] = 0;
                $bv['paid'] = $paidbv;
                $bv['lostl'] = $uex->bv_left - $paidbv;
                $bv['lostr'] = $uex->bv_right - $paidbv;
            }
            $uex->bv_left = $bv['setl'];
            $uex->bv_right = $bv['setr'];
            $uex->save();
            if ($bv['paid'] != 0) {
                createBVLog($user->id, 1, $bv['paid'], 'Paid ' . $bonus . ' ' . $gnl->cur_text . ' For ' . $paidbv . ' BV.');
                createBVLog($user->id, 2, $bv['paid'], 'Paid ' . $bonus . ' ' . $gnl->cur_text . ' For ' . $paidbv . ' BV.');
            }
            if ($bv['lostl'] != 0) {
                createBVLog($user->id, 1, $bv['lostl'], 'Flush ' . $bv['lostl'] . ' BV after Paid ' . $bonus . ' ' . $gnl->cur_text . ' For ' . $paidbv . ' BV.');
            }
            if ($bv['lostr'] != 0) {
                createBVLog($user->id, 2, $bv['lostr'], 'Flush ' . $bv['lostr'] . ' BV after Paid ' . $bonus . ' ' . $gnl->cur_text . ' For ' . $paidbv . ' BV.');
            }
            notify($user, 'matching_bonus', [
                'amount' => $bonus,
                'currency' => $gnl->cur_text,
                'paid_bv' => $weaker,
                'post_balance' => $user->balance,
                'trx' =>  $trx->trx,
            ]);
        }
        return '---';
    }

    function calculateEarnings($principal) {
        $roipercentage = .08;
        $roiperday = (number_format($principal, 2, '.', '') * $roipercentage) / 30;

        $profitpercentage = .04;
        $profitperday = (number_format($principal, 2, '.', '') * $profitpercentage) / 30;
        
        return [
            'roi' => number_format($roiperday, 2, '.', ''),
            'profit' => number_format($profitperday, 2, '.', '')
        ];
    }

    function getReferralDataFromDatabase() {
        $referralData = [];
        $users = DB::table('users')->get();
        foreach ($users as $row) {
            $referralData[$row->id] = $row->ref_id;
        }
        return $referralData;
    }

    function createDynamicUsersArray($referralData) {
        $users = [];

        foreach ($referralData as $userId => $referredBy) {
            // Initialize user if not already in the array
            if (!isset($users[$userId])) {
                $users[$userId] = ['referredBy' => $referredBy, 'directReferrals' => []];
            }

            // Set the referredBy field
            $users[$userId]['referredBy'] = $referredBy;

            // Add this user as a direct referral of the referrer
            if ($referredBy) {
                if (!isset($users[$referredBy])) {
                    $users[$referredBy] = ['referredBy' => null, 'directReferrals' => []];
                }
                $users[$referredBy]['directReferrals'][] = $userId;
            }
        }

        return $users;
    }

    function calculateReferralCommission($users, $principleAmount, $userId) {
        // Referral percentages for levels 1 to 12
        $referralPercentages = [0.02, 0.01, 0.005, 0.0004, 0.0003, 0.0003, 0.0002, 0.0002, 0.0002, 0.0001, 0.0001, 0.0001];
        
        // Commissions array to store results
        $commissions = [];
        
        $currentUserId = $userId;
        $level = 0;

        while ($currentUserId && $level < 12) {
        $currentUser = $users[$currentUserId];
        
        // Check if the current referrer is eligible (must have at least one direct referral)
        if (!empty($currentUser['directReferrals'])) {
            // Calculate the commission for this level
            $commission = ($principleAmount * $referralPercentages[$level]) / 30;
            $commissions[$currentUserId] = $commission;
        }

        // Move up to the next referrer
        $currentUserId = $currentUser['referredBy'] ?? null;
        $level++;
    }
        return $commissions;
    }

    /*public function calculateroiperday() {
        $users = DB::table('users')->get();
        foreach ($users as $usr) {
            $earnings = $this->calculateEarnings($usr->principle_balance);
            $principal = number_format($usr->principle_balance, 2, '.', '') - number_format($earnings['profit'], 2, '.', '');
            $roi = number_format($earnings['roi'], 2, '.', '') + number_format($earnings['profit'], 2, '.', '');
            //$usr->principle_balance = $principal;
            //$user->total_invest += $pamount;
            $usr->total_binary_com += $roi;
            DB::table('users')->where('id', $usr->id)->update(['principle_balance' => number_format($principal, 2, '.', ''), 'total_binary_com' => number_format($usr->total_binary_com, 2, '.', '')]);

            $userInput = $this->getReferralDataFromDatabase();
            $users = $this->createDynamicUsersArray($userInput);
            $commissions = $this->calculateReferralCommission($users, $principal, $usr->ref_id);
            //echo "<pre>"; print_r($commissions);
            foreach ($commissions as $user => $commission) {
                $usr->total_ref_com += $commission;
                DB::table('users')->where('id', $user)->update(['total_ref_com' => number_format($usr->total_ref_com, 2)]);
                DB::table('income_report')->insert(['user_id' => $user, 'roi_amount' => number_format($earnings['roi'], 2, '.', ''), 'profit_amount' => number_format($earnings['profit'], 2, '.', ''), 'referal_amount' => $usr->total_ref_com]);
            }
            //echo "<pre>"; print_r($referralData);
            //return '1';
        }
    }*/
    
    public function calculateroiperday() {
        Log::info('Starting ROI calculation per day');
    
        $users = DB::table('users')->get();
        Log::info('Found ' . count($users) . ' users to process');
    
        foreach ($users as $usr) {
            Log::info('Processing user ID: ' . $usr->id);
    
            // Calculate earnings
            $earnings = $this->calculateEarnings($usr->principle_balance);
            Log::info('Calculated earnings for user ' . $usr->id . ': ', $earnings);
    
            $principal = number_format($usr->principle_balance, 2, '.', '') - number_format($earnings['profit'], 2, '.', '');
            $roi = number_format($earnings['roi'], 2, '.', '') + number_format($earnings['profit'], 2, '.', '');
            
            Log::info('New principal balance for user ' . $usr->id . ': ' . $principal);
            Log::info('New ROI for user ' . $usr->id . ': ' . $roi);
    
            // Update the user record
            DB::table('users')->where('id', $usr->id)->update([
                'principle_balance' => number_format($principal, 2, '.', ''),
                'total_binary_com' => number_format($usr->total_binary_com + $roi, 2, '.', '')
            ]);
    
            Log::info('Updated user ID ' . $usr->id . ' with new principle_balance and total_binary_com');
    
            // Calculate referral commissions
            $userInput = $this->getReferralDataFromDatabase();
            $users = $this->createDynamicUsersArray($userInput);
            $commissions = $this->calculateReferralCommission($users, $principal, $usr->ref_id);
            Log::info('Referral commissions calculated for user ' . $usr->id . ': ', $commissions);
    
            foreach ($commissions as $user => $commission) {
                $usr->total_ref_com += $commission;
                DB::table('users')->where('id', $user)->update([
                    'total_ref_com' => number_format($usr->total_ref_com, 2)
                ]);
                Log::info('Updated referral commission for user ID ' . $user . ': ' . $usr->total_ref_com);
    
                // Insert into income report
                DB::table('income_report')->insert([
                    'user_id' => $user,
                    'roi_amount' => number_format($earnings['roi'], 2, '.', ''),
                    'profit_amount' => number_format($earnings['profit'], 2, '.', ''),
                    'referal_amount' => $usr->total_ref_com
                ]);
                $rfrl_amntdata = DB::table('income_report')->where('user_id', $user)->sum('referal_amount');
                DB::table('users')->where('id', $user)->update(['total_ref_com' => number_format($rfrl_amntdata, 2, '.', '')]);
                Log::info('Income report inserted for user ID ' . $user);
            }
        }
    
        Log::info('Completed ROI calculation per day');
    }
}