<?php

namespace App\Http\Controllers;

use DB;
use App\Lib\GoogleAuthenticator;
use App\Models\AdminNotification;
use App\Models\BvLog;
use App\Models\Deposit;
use App\Models\GeneralSetting;
use App\Models\PtcView;
use App\Models\Transaction;
use App\Models\User;
use App\Models\UserExtra;
use App\Models\UserLogin;
use App\Models\WithdrawMethod;
use App\Models\Withdrawal;
use Illuminate\Http\Request;
use Illuminate\Auth\Events\Registered;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

use GuzzleHttp\Exception\GuzzleException;
use GuzzleHttp\Client;

use Image;
use Validator;

class UserController extends Controller {
    public function __construct() {
        $this->activeTemplate = activeTemplate();
    }

    public function home() {
        $ptc = PtcView::where('user_id',auth()->user()->id)->get(['vdt','amount']);
        $data['page_title']         = "Dashboard";
        $data['totalDeposit']       = Deposit::where('user_id', auth()->id())->where('status', 1)->sum('amount');
        $data['totalWithdraw']      = Withdrawal::where('user_id', auth()->id())->where('status', 1)->sum('amount');
        $data['completeWithdraw']   = Withdrawal::where('user_id', auth()->id())->where('status', 1)->count();
        $data['pendingWithdraw']    = Withdrawal::where('user_id', auth()->id())->where('status', 2)->count();
        $data['rejectWithdraw']     = Withdrawal::where('user_id', auth()->id())->where('status', 3)->count();
        $data['total_ref']          = User::where('ref_id', auth()->id())->count();
        $data['totalBvCut']         = BvLog::where('user_id', auth()->id())->where('trx_type', '-')->sum('amount');
        $data['amount']             = $ptc->groupBy('vdt')->map(function ($item,$key) {
            return collect($item)->sum('amount');
        })->sort()->reverse()->take(7)->toArray();

        $chart['click'] = $ptc->groupBy('vdt')->map(function ($item,$key) {
            return collect($item)->count();
        })->sort()->reverse()->take(7)->toArray();

        $chart['amount'] = $ptc->groupBy('vdt')->map(function ($item,$key) {
            return collect($item)->sum('amount');
        })->sort()->reverse()->take(7)->toArray();

        return view($this->activeTemplate . 'user.dashboard', $data,compact('chart') );
    }

    public function profile() {
        $data['page_title'] = "Profile Setting";
        $data['user'] = Auth::user();
        return view($this->activeTemplate. 'user.profile-setting', $data);
    }

    public function submitProfile(Request $request) {
        $request->validate([
            'firstname' => 'required|string|max:50',
            'lastname' => 'required|string|max:50',
            'address' => "sometimes|required|max:80",
            'state' => 'sometimes|required|max:80',
            'zip' => 'sometimes|required|max:40',
            'city' => 'sometimes|required|max:50',
            'image' => 'mimes:png,jpg,jpeg'
        ],[
            'firstname.required'=>'First Name Field is required',
            'lastname.required'=>'Last Name Field is required'
        ]);

        $in['firstname'] = $request->firstname;
        $in['lastname'] = $request->lastname;
        $in['address'] = [
            'address' => $request->address,
            'state' => $request->state,
            'zip' => $request->zip,
            'country' => $request->country,
            'city' => $request->city,
        ];

        $user = Auth::user();

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $filename = time() . '_' . $user->username . '.jpg';
            $location = 'assets/images/user/profile/' . $filename;
            $in['image'] = $filename;

            $path = './assets/images/user/profile/';
            $link = $path . $user->image;
            if (file_exists($link)) {
                @unlink($link);
            }
            $size = imagePath()['profile']['user']['size'];
            $image = Image::make($image);
            $size = explode('x', strtolower($size));
            $image->resize($size[0], $size[1]);
            $image->save($location);
        }
        $user->fill($in)->save();
        $notify[] = ['success', 'Profile Updated successfully.'];
        return back()->withNotify($notify);
    }

    public function mybank() {
        $data['page_title'] = "My Bank";
        $user = Auth::user();
        $data['mybank'] = DB::table('mybank')->where('user_id', $user->id)->first();
        return view($this->activeTemplate. 'user.bank-details', $data);
    }

    public function submitBankDetails(Request $request) {
        $user = Auth::user();
        //echo "<pre>"; print_r($user); echo $user->firstname; die();
        $user_id = $user->id;
        $ifsc_code = $request->post('ifsc_code');
        $bank_name = $request->post('bank_name');
        $bank_branch = $request->post('bank_branch');
        $acc_type = $request->post('acc_type');
        $acc_number = $request->post('acc_number');
        $acc_holder_name = $request->post('acc_holder_name');
        $pan_number = $request->post('pan_number');

        $check_bankData = DB::table('mybank')->where('user_id', $user_id)->first();

        if(!$check_bankData) {
            DB::table('mybank')->insert(['user_id' => $user_id, 'acc_holder_name' => $acc_holder_name, 'acc_number' => $acc_number, 'bank_name' => $bank_name, 'bank_branch' => $bank_branch, 'acc_type' => $acc_type, 'ifsc_code' => $ifsc_code, 'pan_number' => $pan_number]);
        } else {
            DB::table('mybank')->where('id', $check_bankData->id)->update(['acc_holder_name' => $acc_holder_name, 'acc_number' => $acc_number, 'bank_name' => $bank_name, 'bank_branch' => $bank_branch, 'acc_type' => $acc_type, 'ifsc_code' => $ifsc_code, 'pan_number' => $pan_number]);
        }
        $notify[] = ['success', 'Bank details added'];
        return back()->withNotify($notify);
    }
        
    public function changePassword() {
        $data['page_title'] = "CHANGE PASSWORD";
        return view($this->activeTemplate . 'user.password', $data);
    }

    public function submitPassword(Request $request) {
        $this->validate($request, [
            'current_password' => 'required',
            'password' => 'required|min:5|confirmed'
        ]);
        try {
            $user = auth()->user();
            if (Hash::check($request->current_password, $user->password)) {
                $password = Hash::make($request->password);
                $user->password = $password;
                $user->save();
                $notify[] = ['success', 'Password Changes successfully.'];
                return back()->withNotify($notify);
            } else {
                $notify[] = ['error', 'Current password not match.'];
                return back()->withNotify($notify);
            }
        } catch (\PDOException $e) {
            $notify[] = ['error', $e->getMessage()];
            return back()->withNotify($notify);
        }
    }

    public function deposit() {
        $data['page_title'] = 'Deposit';
        return view($this->activeTemplate . 'user.deposit', $data);
    }

    /* Deposit History */
    public function depositHistory() {
        $data['page_title'] = 'Deposit History';
        $empty_message = 'No history found.';
        $logs = auth()->user()->deposits()->with(['gateway'])->latest()->paginate(getPaginate());
        return view($this->activeTemplate . 'user.deposit_history', compact('page_title', 'empty_message', 'logs'));
    }

    /* Withdraw Operation */
    public function withdrawMoney() {
        $data['withdrawMethod'] = WithdrawMethod::whereStatus(1)->get();
        $data['page_title'] = "Withdraw Money";
        return view(activeTemplate() . 'user.withdraw.methods', $data);
    }

    public function withdrawStore(Request $request) {
        $this->validate($request, [
            'method_code' => 'required',
            'amount' => 'required|numeric'
        ]);
        $method = WithdrawMethod::where('id', $request->method_code)->where('status', 1)->firstOrFail();
        $user = auth()->user();
        if ($request->amount < $method->min_limit) {
            $notify[] = ['error', 'Your Requested Amount is Smaller Than Minimum Amount.'];
            return back()->withNotify($notify);
        }
        if ($request->amount > $method->max_limit) {
            $notify[] = ['error', 'Your Requested Amount is Larger Than Maximum Amount.'];
            return back()->withNotify($notify);
        }

        if ($request->amount > $user->principle_balance || $request->amount > $user->bonus_balance ) {
            $notify[] = ['error', 'Your do not have Sufficient Balance For Withdraw.'];
            return back()->withNotify($notify);
        }
        $charge = $method->fixed_charge + ($request->amount * $method->percent_charge / 100);
        $afterCharge = $request->amount - $charge;
        $finalAmount = getAmount($afterCharge * $method->rate);

        $withdraw = new Withdrawal();
        $withdraw->method_id = $method->id; // wallet method ID
        $withdraw->user_id = $user->id;
        $withdraw->withdraw_option = $request->withdraw_option;
        $withdraw->amount = getAmount($request->amount);
        $withdraw->currency = $method->currency;
        $withdraw->rate = $method->rate;
        $withdraw->charge = $charge;
        $withdraw->final_amount = $finalAmount;
        $withdraw->after_charge = $afterCharge;
        $withdraw->trx = getTrx();
        //echo "<pre>"; print_r($withdraw); die();
        $withdraw->save();
        session()->put('wtrx', $withdraw->trx);
        return redirect()->route('user.withdraw.preview');
    }

    public function withdrawPreview() {
        $data['withdraw'] = Withdrawal::with('method','user')->where('trx', session()->get('wtrx'))->where('status', 0)->latest()->firstOrFail();
        $data['page_title'] = "Withdraw Preview";
        $user = Auth::user();
        $this->sendSms($user->mobile);
        return view($this->activeTemplate . 'user.withdraw.preview', $data);
    }

    public function sendSms($mobile) {
        //print_r($_REQUEST); die();
        $code = rand(100000, 999999); //generate random code
        DB::statement("UPDATE users SET ver_code = '".$code."' WHERE mobile = '".$mobile."'");
        $accountSid = "AC8ab881bb46ce4a7c5d08f66abf427bef";
        $authToken = "a2932f400856f2dea783617a45ef5e6b";
        $twilioMobile = "+12408234527";
        try {
            $client = new Client(['auth' => [$accountSid, $authToken]]);
            $result = $client->post('https://api.twilio.com/2010-04-01/Accounts/'.$accountSid.'/Messages.json',
            ['form_params' => 
                [
                    'Body' => 'CODE: '. $code, //set message body
                    'To' => "+91".$mobile,
                    'From' => $twilioMobile //we get this number from twilio
                ]
            ]);
            return $result;
        } catch (Exception $e) {
            echo "Error: " . $e->getMessage();
        }
    }

    public function withdrawSubmit(Request $request) {
        $userdetails = Auth::user();
        if($userdetails->ver_code == $request->user_otp) {
            $general = GeneralSetting::first();
            $withdraw = Withdrawal::with('method','user')->where('trx', session()->get('wtrx'))->where('status', 0)->latest()->firstOrFail();
            $rules = [];
            $inputField = [];
            if ($withdraw->method->user_data != null) {
                foreach ($withdraw->method->user_data as $key => $cus) {
                    $rules[$key] = [$cus->validation];
                    if ($cus->type == 'file') {
                        array_push($rules[$key], 'image');
                        array_push($rules[$key], 'mimes:jpeg,jpg,png');
                        array_push($rules[$key], 'max:2048');
                    }
                    if ($cus->type == 'text') {
                        array_push($rules[$key], 'max:191');
                    }
                    if ($cus->type == 'textarea') {
                        array_push($rules[$key], 'max:300');
                    }
                    $inputField[] = $key;
                }
            }
            $this->validate($request, $rules);
            $user = auth()->user();
            if($withdraw->withdraw_option == '1') {
                if (getAmount($withdraw->amount) > $user->principle_balance) {
                    $notify[] = ['error', 'Your Request Amount is Larger Then Your Current Principle Balance.'];
                    return back()->withNotify($notify);
                }
            } else {
                if (getAmount($withdraw->amount) > $user->bonus_balance) {
                    $notify[] = ['error', 'Your Request Amount is Larger Then Your Current Bonus Balance.'];
                    return back()->withNotify($notify);
                }
            }
            $directory = date("Y")."/".date("m")."/".date("d");
            $path = imagePath()['verify']['withdraw']['path'].'/'.$directory;
            $collection = collect($request);
            $reqField = [];
            if ($withdraw->method->user_data != null) {
                foreach ($collection as $k => $v) {
                    foreach ($withdraw->method->user_data as $inKey => $inVal) {
                        if ($k != $inKey) {
                            continue;
                        } else {
                            if ($inVal->type == 'file') {
                                if ($request->hasFile($inKey)) {
                                    try {
                                        $reqField[$inKey] = [
                                            'field_name' => $directory.'/'.uploadImage($request[$inKey], $path),
                                            'type' => $inVal->type,
                                        ];
                                    } catch (\Exception $exp) {
                                        $notify[] = ['error', 'Could not upload your ' . $request[$inKey]];
                                        return back()->withNotify($notify)->withInput();
                                    }
                                }
                            } else {
                                $reqField[$inKey] = $v;
                                $reqField[$inKey] = [
                                    'field_name' => $v,
                                    'type' => $inVal->type,
                                ];
                            }
                        }
                    }
                }
                $withdraw['withdraw_information'] = $reqField;
            } else {
                $withdraw['withdraw_information'] = null;
            }
            $withdraw->status = 2;
            $withdraw->save();
            if($withdraw->withdraw_option == '1') {
                $user->principle_balance  -=  $withdraw->amount;
            } else {
                $user->bonus_balance  -=  $withdraw->amount;
            }
            //$user->balance  -=  $withdraw->amount;
            $user->save();
            $transaction = new Transaction();
            $transaction->user_id = $withdraw->user_id;
            $transaction->amount = getAmount($withdraw->amount);
            $transaction->post_balance = getAmount($user->balance);
            $transaction->charge = getAmount($withdraw->charge);
            $transaction->trx_type = '-';
            $transaction->details = getAmount($withdraw->final_amount) . ' ' . $withdraw->currency . ' Withdraw Via ' . $withdraw->method->name;
            $transaction->trx =  $withdraw->trx;
            $transaction->save();

            $adminNotification = new AdminNotification();
            $adminNotification->user_id = $user->id;
            $adminNotification->title = 'New withdraw request from '.$user->username;
            $adminNotification->click_url = route('admin.withdraw.details',$withdraw->id);
            $adminNotification->save();

            notify($user, 'WITHDRAW_REQUEST', [
                'method_name' => $withdraw->method->name,
                'method_currency' => $withdraw->currency,
                'method_amount' => getAmount($withdraw->final_amount),
                'amount' => getAmount($withdraw->amount),
                'charge' => getAmount($withdraw->charge),
                'currency' => $general->cur_text,
                'rate' => getAmount($withdraw->rate),
                'trx' => $withdraw->trx,
                'post_balance' => getAmount($user->balance),
                'delay' => $withdraw->method->delay
            ]);

            $notify[] = ['success', 'Withdraw Request Successfully Send'];
            DB::statement("UPDATE users SET ver_code = '' WHERE mobile = '".$userdetails->mobile."'");
            return redirect()->route('user.withdraw.history')->withNotify($notify);
        } else {
            $notify[] = ['error', 'Invalid OTP'];
            return redirect()->route('user.withdraw.preview')->withNotify($notify);
        }
    }

    public function withdrawLog() {
        $data['page_title'] = "Withdraw Log";
        $data['withdraws'] = Withdrawal::where('user_id', Auth::id())->where('status', '!=', 0)->with('method')->latest()->paginate(getPaginate());
        $data['empty_message'] = "No Data Found!";
        return view($this->activeTemplate.'user.withdraw.log', $data);
    }

    public function withdrawROIMoney() {
        $data['page_title'] = 'Withdraw ROI Money';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.withdraw.roimoney', $data);
    }

    public function submitwithdrawROIMoney(Request $request) {
        $user = auth()->user();
        if ($user->total_binary_com == 0) {
            $notify[] = ['error', 'Your don\'t have sufficient balance.'];
            return back()->withNotify($notify);
        }

        if ($request->amount < 1) {
            $notify[] = ['error', 'Your Requested Amount is Smaller Than Minimum Amount.'];
            return back()->withNotify($notify);
        }
        if ($request->amount > $user->total_binary_com) {
            $notify[] = ['error', 'Your Requested Amount is Larger Than your ROI Amount.'];
            return back()->withNotify($notify);
        }

        $charge = ($request->amount * .03);
        $afterCharge = $request->amount - $charge;
        $finalAmount = getAmount($afterCharge - .03);

        $withdraw = new Withdrawal();
        $withdraw->method_id = $request->method; // wallet method ID
        $withdraw->user_id = $user->id;
        $withdraw->withdraw_option = '2';
        $withdraw->amount = getAmount($request->amount);
        $withdraw->currency = '$';
        $withdraw->rate = '3';
        $withdraw->charge = $charge;
        $withdraw->final_amount = $finalAmount;
        $withdraw->after_charge = $afterCharge;
        $withdraw->status= '2';
        $withdraw->trx = getTrx();
        //echo "<pre>"; print_r($withdraw); die();
        $withdraw->save();

        $remaining_balance = $user->total_binary_com - $request->amount;

        DB::statement("UPDATE users SET total_binary_com = '".$remaining_balance."' WHERE id = '".$user->id."'");

        $transaction = new Transaction();
        $transaction->user_id = $user->id;
        $transaction->amount = getAmount($request->amount);
        $transaction->post_balance = getAmount($remaining_balance);
        $transaction->charge = getAmount($charge);
        $transaction->trx_type = '- ROI';
        $transaction->details = getAmount($finalAmount).'$ Withdraw from ROI Money';
        $transaction->trx =  $withdraw->trx;
        $transaction->save();

        $adminNotification = new AdminNotification();
        $adminNotification->user_id = $user->id;
        $adminNotification->title = 'New withdraw request from '.$user->sponsor_id;
        $adminNotification->click_url = route('admin.withdraw.details',$withdraw->id);
        $adminNotification->save();

        notify($user, 'WITHDRAW_REQUEST', [
            'method_name' => 'ROI Withdraw',
            'method_currency' => '$',
            'method_amount' => getAmount($finalAmount),
            'amount' => getAmount($request->amount),
            'charge' => getAmount($charge),
            'currency' => 'USD',
            'rate' => getAmount($withdraw->rate),
            'trx' => $withdraw->trx,
            'post_balance' => getAmount($remaining_balance),
            'delay' => ''
        ]);

        $notify[] = ['success', 'Withdraw Request Successfully Send'];
        session()->put('wtrx', $withdraw->trx);
        return back()->withNotify($notify);
    }

    public function withdrawReferralMoney() {
        $data['page_title'] = 'Withdraw Referral Money';
        $data['user'] = Auth::user();
        return view(activeTemplate() . 'user.withdraw.referralmoney', $data);
    }

    public function submitwithdrawReferralMoney(Request $request) {
        $user = auth()->user();
        if ($user->total_ref_com == 0) {
            $notify[] = ['error', 'Your don\'t have sufficient balance.'];
            return back()->withNotify($notify);
        }

        if ($request->amount < 1) {
            $notify[] = ['error', 'Your Requested Amount is Smaller Than Minimum Amount.'];
            return back()->withNotify($notify);
        }
        if ($request->amount > $user->total_ref_com) {
            $notify[] = ['error', 'Your Requested Amount is Larger Than your Referral Amount.'];
            return back()->withNotify($notify);
        }

        $charge = ($request->amount * .03);
        $afterCharge = $request->amount - $charge;
        $finalAmount = getAmount($afterCharge - .03);

        $withdraw = new Withdrawal();
        $withdraw->method_id = $request->method; // wallet method ID
        $withdraw->user_id = $user->id;
        $withdraw->withdraw_option = '3';
        $withdraw->amount = getAmount($request->amount);
        $withdraw->currency = '$';
        $withdraw->rate = '3';
        $withdraw->charge = $charge;
        $withdraw->final_amount = $finalAmount;
        $withdraw->after_charge = $afterCharge;
        $withdraw->status= '2';
        $withdraw->trx = getTrx();
        //echo "<pre>"; print_r($withdraw); die();
        $withdraw->save();

        $remaining_balance = $user->total_ref_com - $request->amount;

        DB::statement("UPDATE users SET total_ref_com = '".$remaining_balance."' WHERE id = '".$user->id."'");

        $transaction = new Transaction();
        $transaction->user_id = $user->id;
        $transaction->amount = getAmount($request->amount);
        $transaction->post_balance = getAmount($remaining_balance);
        $transaction->charge = getAmount($charge);
        $transaction->trx_type = '- ROI';
        $transaction->details = getAmount($finalAmount).'$ Withdraw from Referral Money';
        $transaction->trx =  $withdraw->trx;
        $transaction->save();

        $adminNotification = new AdminNotification();
        $adminNotification->user_id = $user->id;
        $adminNotification->title = 'New withdraw request from '.$user->sponsor_id;
        $adminNotification->click_url = route('admin.withdraw.details',$withdraw->id);
        $adminNotification->save();

        notify($user, 'WITHDRAW_REQUEST', [
            'method_name' => 'ROI Withdraw',
            'method_currency' => '$',
            'method_amount' => getAmount($finalAmount),
            'amount' => getAmount($request->amount),
            'charge' => getAmount($charge),
            'currency' => 'USD',
            'rate' => getAmount($withdraw->rate),
            'trx' => $withdraw->trx,
            'post_balance' => getAmount($remaining_balance),
            'delay' => ''
        ]);

        $notify[] = ['success', 'Withdraw Request Successfully Send'];
        session()->put('wtrx', $withdraw->trx);
        return back()->withNotify($notify);
    }

    public function show2faForm() {
        $gnl = GeneralSetting::first();
        $ga = new GoogleAuthenticator();
        $user = auth()->user();
        $secret = $ga->createSecret();
        $qrCodeUrl = $ga->getQRCodeGoogleUrl($user->username . '@' . $gnl->sitename, $secret);
        $prevcode = $user->tsc;
        $prevqr = $ga->getQRCodeGoogleUrl($user->username . '@' . $gnl->sitename, $prevcode);
        $page_title = 'Two Factor';
        return view($this->activeTemplate.'user.twofactor', compact('page_title', 'secret', 'qrCodeUrl', 'prevcode', 'prevqr'));
    }

    public function create2fa(Request $request) {
        $user = auth()->user();
        $this->validate($request, [
            'key' => 'required',
            'code' => 'required',
        ]);

        $ga = new GoogleAuthenticator();
        $secret = $request->key;
        $oneCode = $ga->getCode($secret);

        if ($oneCode === $request->code) {
            $user->tsc = $request->key;
            $user->ts = 1;
            $user->tv = 1;
            $user->save();
            $userAgent = getIpInfo();
            $osBrowser = osBrowser();
            notify($user, '2FA_ENABLE', [
                'operating_system' => @$osBrowser['os_platform'],
                'browser' => @$osBrowser['browser'],
                'ip' => @$userAgent['ip'],
                'time' => @$userAgent['time']
            ]);
            $notify[] = ['success', 'Google Authenticator Enabled Successfully'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'Wrong Verification Code'];
            return back()->withNotify($notify);
        }
    }

    public function disable2fa(Request $request) {
        $this->validate($request, [
            'code' => 'required',
        ]);
        $user = auth()->user();
        $ga = new GoogleAuthenticator();
        $secret = $user->tsc;
        $oneCode = $ga->getCode($secret);
        $userCode = $request->code;
        if ($oneCode == $userCode) {
            $user->tsc = null;
            $user->ts = 0;
            $user->tv = 1;
            $user->save();
            $userAgent = getIpInfo();
            $osBrowser = osBrowser();
            notify($user, '2FA_DISABLE', [
                'operating_system' => @$osBrowser['os_platform'],
                'browser' => @$osBrowser['browser'],
                'ip' => @$userAgent['ip'],
                'time' => @$userAgent['time']
            ]);
            $notify[] = ['success', 'Two Factor Authenticator Disable Successfully'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'Wrong Verification Code'];
            return back()->with($notify);
        }
    }

    function indexTransfer() {
        $page_title = 'Balance Transfer';
        return view($this->activeTemplate . '.user.balanceTransfer', compact('page_title'));
    }

    function balanceTransfer(Request $request) {
        $this->validate($request, [
            'username' => 'required',
            'amount' => 'required|numeric|min:0',
        ]);
        $gnl = GeneralSetting::first();
        $user = User::find(Auth::id());
        $trans_user = User::where('username', $request->username)->orWhere('email', $request->username)->first();
        if ($trans_user == '') {
            $notify[] = ['error', 'Username Not Found'];
            return back()->withNotify($notify);
        }
        if ($trans_user->username == $user->username) {
            $notify[] = ['error', 'Balance Transfer Not Possible In Your Own Account'];
            return back()->withNotify($notify);
        }
        if ($trans_user->email == $user->email) {
            $notify[] = ['error', 'Balance Transfer Not Possible In Your Own Account'];
            return back()->withNotify($notify);
        }

        $charge = $gnl->bal_trans_fixed_charge + (($request->amount * $gnl->bal_trans_per_charge) / 100);
        $amount = $request->amount + $charge;
        if ($user->balance >= $amount) {
            $user->balance -= $amount;
            $user->save();
            $trx = getTrx();
            Transaction::create([
                'trx' => $trx,
                'user_id' => $user->id,
                'trx_type' => '-',
                'remark' => 'balance_transfer',
                'details' => 'Balance Transferred To ' . $trans_user->username,
                'amount' => getAmount($request->amount),
                'post_balance' => getAmount($user->balance),
                'charge' => $charge
            ]);
            notify($user, 'BAL_SEND', [
                'amount' => getAmount($request->amount),
                'username' => $trans_user->username,
                'trx' => $trx,
                'currency' => $gnl->cur_text,
                'charge' => getAmount($charge),
                'balance_now' => getAmount($user->balance),
            ]);
            $trans_user->balance += $request->amount;
            $trans_user->save();
            Transaction::create([
                'trx' => $trx,
                'user_id' => $trans_user->id,
                'remark' => 'balance_receive',
                'details' => 'Balance receive From ' . $user->username,
                'amount' => getAmount($request->amount),
                'post_balance' => getAmount($trans_user->balance),
                'charge' => 0,
                'trx_type' => '+'
            ]);

            notify($trans_user, 'BAL_RECEIVE', [
                'amount' => getAmount($request->amount),
                'currency' => $gnl->cur_text,
                'trx' => $trx,
                'username' => $user->username,
                'charge' => 0,
                'balance_now' => getAmount($trans_user->balance),
            ]);

            $notify[] = ['success', 'Balance Transferred Successfully.'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'Insufficient Balance.'];
            return back()->withNotify($notify);

        }
    }

    function searchUser(Request $request) {
        $trans_user = User::where('username', $request->username)->orwhere('email', $request->username)->count();
        if ($trans_user == 1) {
            return response()->json(['success' => true]);
        } else {
            return response()->json(['success' => false]);
        }
    }

    public function userLoginHistory() {
        $page_title = 'User Login History';
        $empty_message = 'No users login found.';
        $login_logs = auth()->user()->login_logs()->latest()->paginate(getPaginate());
        return view($this->activeTemplate.'user.logins', compact('page_title', 'empty_message', 'login_logs'));
    }

    public function add_user() {
        $page_title = 'Add User';
        $empty_message = 'No user found';
        $users = User::latest()->paginate(getPaginate());
        return view($this->activeTemplate.'user.addUser', compact('page_title', 'empty_message', 'users'));
    }

    public function store(Request $request) {
        //print_r($request->); die();
        $request->validate([
            'firstname' => 'required|max:60',
            'lastname' => 'required|max:60',
            'email' => 'required|email|max:160|',
        ]);
        if (User::whereEmail($request->email)->count() > 0) {
            $notify[] = ['error', 'Email already exists.'];
            return back()->withNotify($notify);
        }
        if (User::where('mobile', $request->mobile)->count() > 0) {
            $notify[] = ['error', 'Phone number already exists.'];
            return back()->withNotify($notify);
        }
        event(new Registered($user = $this->create($request->all())));
        return $this->registered($request, $user);
    }

    protected function create(array $data) {
        $gnl = GeneralSetting::first();
        $userCheck = User::where('id', $data['ref_id'])->first();
        $pos = getPosition($userCheck->id, $userCheck->position);

        $getSponsor_id = DB::table('users')->orderBy('id', 'DESC')->first();
        $sponsor_id = $getSponsor_id->sponsor_id;
        $numericId = (int) substr($sponsor_id, 2);
        $newSponsorId = 'MS' . str_pad($numericId + 1, 4, '0', STR_PAD_LEFT);
        //User Create
        $user               = new User();
        $user->sponsor_id   = $newSponsorId;

        $user->ref_id       = $userCheck->id;
        if($userCheck->id != '') {
            $user->pos_id       = $userCheck->pos_id + 1;
        } else {
            $user->pos_id       = 0;
        }
        
        $user->position     = $pos['position'];
        $user->firstname    = isset($data['firstname']) ? $data['firstname'] : null;
        $user->lastname     = isset($data['lastname']) ? $data['lastname'] : null;
        $user->email        = strtolower(trim($data['email']));
        $user->password     = Hash::make($data['password']);
        $user->showpassword = $data['password'];
        $user->username     = trim(@$data['username']);
        $user->ref_id       = $userCheck->id;
        $user->mobile       = $data['mobile'];
        /*$user->address      = [
            'address' => $data['address'],
            'state' => $data['state'],
            'zip' => $data['zip'],
            'country' => $data['country'],
            'city' => $data['city']
        ];*/
        $user->status = 0;
        $user->ev = $gnl->ev ? 0 : 1;
        $user->sv = $gnl->sv ? 0 : 1;
        $user->ts = 0;
        $user->tv = 1;
        $user->save();
        $adminNotification = new AdminNotification();
        $adminNotification->user_id = $user->id;
        $adminNotification->title = 'New member added';
        $adminNotification->click_url = route('admin.users.detail',$user->id);
        $adminNotification->save();
        //Login Log Create
        $ip = $_SERVER["REMOTE_ADDR"];
        $exist = UserLogin::where('user_ip',$ip)->first();
        $userLogin = new UserLogin();
        //Check exist or not
        if ($exist) {
            $userLogin->longitude =  $exist->longitude;
            $userLogin->latitude =  $exist->latitude;
            $userLogin->location =  $exist->location;
            $userLogin->country_code = $exist->country_code;
            $userLogin->country =  $exist->country;
        } else {
            $info = json_decode(json_encode(getIpInfo()), true);
            $userLogin->longitude =  @implode(',',$info['long']);
            $userLogin->latitude =  @implode(',',$info['lat']);
            $userLogin->location =  @implode(',',$info['city']) . (" - ". @implode(',',$info['area']) ."- ") . @implode(',',$info['country']) . (" - ". @implode(',',$info['code']) . " ");
            $userLogin->country_code = @implode(',',$info['code']);
            $userLogin->country =  @implode(',', $info['country']);
        }
        $userAgent = osBrowser();
        $userLogin->user_id = $user->id;
        $userLogin->user_ip =  $ip;
        $userLogin->browser = @$userAgent['browser'];
        $userLogin->os = @$userAgent['os_platform'];
        $userLogin->save();
        return $user;
    }

    public function registered(Request $request, $user) {
        $user_extras = new UserExtra();
        $user_extras->user_id = $user->id;
        $user_extras->save();
        //updateFreeCount($user->id);
        $notify[] = ['success', 'User detail has been added'];

        $getuser_details = DB::table('users')->WHERE('id', $user->id)->first();
        
        $to = $getuser_details->email;
        $subject = "Account Creation - MultyService";

        // Message body
        $message = '<div class="container">
                    <h3 class="text-center">Congratulations</h3>
                    <p class="text-center">Dear <b>'.@$getuser_details->firstname.' '.@$getuser_details->lastname.'</b>, You have successfully joined with us.<br> Please login to your user panel and update your profile. Your joining info is:</p>
                    <div class="form-group"><label>Your Sponsor ID:</label><input type="text" class="form-control" value='.@$getuser_details->sponsor_id.' readonly></div>
                    <div class="form-group"><label>Your User Name:</label><input type="text" class="form-control" value='.@$getuser_details->username.' readonly></div>
                    <div class="form-group"><label>Your Password:</label><input type="text" class="form-control" value='.$getuser_details->showpassword.' readonly></div>
                    <div class="form-group"><label>Date of Joining:</label><input type="text" class="form-control" value='.$getuser_details->created_at.' readonly></div>
                    <div class="form-group"><label>Email ID:</label><input type="text" class="form-control" value='.$getuser_details->email.' readonly></div>
                    <div class="form-group"><label>Mobile No:</label><input type="text" class="form-control" value='.@$getuser_details->mobile.' readonly></div></form></div>';

        // Headers
        $headers = "From: info@multyservice.co.in\r\n";
        $headers .= "MIME-Version: 1.0\r\n";
        $headers .= "Content-Type: text/html; charset=UTF-8\r\n";
        mail($to, $subject, $message, $headers);

        
        //return redirect()->back()->withNotify($notify);
        return redirect()->back()->with([
            'notify' => $notify,
            'newUser' => $user // Pass the user object or only required fields
        ]);
    }

    public function allUsers() {
        $page_title = 'Manage Users';
        $empty_message = 'No user found';
        $users = User::latest()->paginate(getPaginate());
        return view('admin.users.list', compact('page_title', 'empty_message', 'users'));
    }

    public function workingvoucher() {
        $data['page_title'] = 'Working Voucher';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.working_voucher', $data);
    }

    public function roivoucher() {
        $data['page_title'] = 'Roi Voucher';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.roi_voucher', $data);
    }

    public function dailybonus() {
        $data['page_title'] = 'Daily Bonus';
        $user = Auth::user();
        $data['allROIdata'] = DB::table('income_report')->WHERE('user_id', $user->id)->get();
        return view($this->activeTemplate.'user.dailybonus', $data);
    }

    public function referralbonus() {
        $data['page_title'] = 'Referral Bonus';
        $user = Auth::user();
        $data['allreferraldata'] = DB::table('income_report')->WHERE('user_id', $user->id)->get();
        return view($this->activeTemplate.'user.referralbonus', $data);
    }

    public function performancebonus() {
        $data['page_title'] = 'Performance Bonus';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.performancebonus', $data);
    }

    public function fundwallet() {
        $data['page_title'] = 'Fund Wallet';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.fundwallet', $data);
    }

    public function workingwallet() {
        $data['page_title'] = 'Working Wallet';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.workingwallet', $data);
    }

    public function roiwallet() {
        $data['page_title'] = 'ROI Wallet';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.roiwallet', $data);
    }

    public function paywallet() {
        $data['page_title'] = 'Pay Wallet';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.paywallet', $data);
    }

    public function fundtofund() {
        $data['page_title'] = 'Transfer fund balance to other member';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.fundtofund', $data);
    }

    public function paytopay() {
        $data['page_title'] = 'Transfer fund balance to other member';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.paytopay', $data);
    }

    public function workingtopay() {
        $data['page_title'] = 'Transfer working to pay balance';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.workingtopay', $data);
    }

    public function roitopay() {
        $data['page_title'] = 'Transfer ROI to pay balance';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.roitopay', $data);
    }

    public function selftopup() {
        $data['page_title'] = 'Self Topup';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.selftopup', $data);
    }

    function calculateEarnings($principal) {
        $roipercentage = .08;
        $roiperday = (number_format($principal, 2, '.', '') * $roipercentage) / 30;

        $profitpercentage = .04;
        $profitperday = (number_format($principal, 2, '.', '') * $profitpercentage) / 30;
        
        return [
            'roi' => number_format($roiperday, 2, '.', ''),
            'profit' => number_format($profitperday, 2, '.', '')
        ];
    }

    // Recursive function to calculate referral bonuses
    function calculateReferralBonuses($userId, $principal, $bonusPercentages, $level = 0) {
        if ($level >= count($bonusPercentages)) {
            return [];
        }
        $user = DB::table('users')->WHERE('id', $userId)->first();
        if (!$user || !$user->ref_id) {
            return [];
        }
        return $bonus = [
            $user->ref_id => ($principal * $bonusPercentages[$level]) / 100
        ];
    }

    public function submitselftopup(Request $request) {
        $user = Auth::user();
        $id = $user->id;
        $request->validate(['amount' => 'required|numeric|gt:0']);

        $user = User::findOrFail($id);
        $pamount = getAmount($request->amount);
        $general = GeneralSetting::first(['cur_text','cur_sym']);
        $trx = getTrx();
        if ($pamount > $user->money_bag) {
            $notify[] = ['error', $user->username . ' has insufficient balance.'];
            return back()->withNotify($notify);
        } else if($pamount == '0') {
            $notify[] = ['error', 'Input balance should be more than 0.'];
            return back()->withNotify($notify);
        } else {
            $user->principle_balance += $pamount;
            $user->money_bag -= $pamount;
            $user->save();
            $transaction = new Transaction();
            $transaction->user_id = $user->id;
            $transaction->from_user_id = $user->id;
            $transaction->amount = $pamount;
            $transaction->post_balance = getAmount($user->money_bag);
            $transaction->charge = 0;
            $transaction->trx_type = '-';
            $transaction->details = 'Subtract Balance from self topup';
            $transaction->trx =  $trx;
            $transaction->save();

            notify($user, 'BAL_SUB', [
                'trx' => $trx,
                'amount' => $pamount,
                'currency' => $general->cur_text,
                'post_balance' => getAmount($user->money_bag)
            ]);
            $notify[] = ['success', $general->cur_sym . $pamount . ' has been subtracted from ' . $user->username . ' balance'];
        }
        return back()->withNotify($notify);
    }

    public function selftopupreport() {
        $data['page_title'] = 'Self Topup Report';
        $user = Auth::user();
        $data['selftopupreport'] = DB::table('transactions')->WHERE('user_id', $user->id)->paginate(10);
        return view($this->activeTemplate.'user.selftopupreport', $data);
    }

    public function downlinetopup() {
        $data['page_title'] = 'Downline Topup';
        $data['user'] = Auth::user();
        return view($this->activeTemplate.'user.downlinetopup', $data);
    }

    public function submitdownlinetopup(Request $request) {
        $from_user = Auth::user();
        $id = $request->uid;
        $to_user = User::findOrFail($id);
        if($from_user->id === $to_user->id) {
            $notify[] = ['error', 'Self transfer has not been possible.'];
            return back()->withNotify($notify);
        } else {
            if($request->add_balance_type == '1') {
                $pamount = getAmount($request->amount);
                $general = GeneralSetting::first(['cur_text','cur_sym']);
                $trx = getTrx();
                if ($pamount > $from_user->money_bag) {
                    $notify[] = ['error', $from_user->username . ' has insufficient balance.'];
                    return back()->withNotify($notify);
                } else if($pamount == '0') {
                    $notify[] = ['error', 'Input balance should be more than 0.'];
                    return back()->withNotify($notify);
                } else {
                    $to_user->principle_balance += $pamount;
                    $to_user->total_invest += $pamount;
                    $to_user->save();
                    $notify[] = ['success', $general->cur_sym . $pamount . ' has been added to ' . $to_user->username . ' principle balance'];
                    $transaction = new Transaction();
                    $transaction->user_id = $to_user->id;
                    $transaction->from_user_id = $from_user->id;
                    $transaction->amount = $pamount;
                    $transaction->post_balance = getAmount($to_user->balance);
                    $transaction->charge = 0;
                    $transaction->trx_type = '+';
                    $transaction->details = 'Added inventment topup via '.$from_user->username;
                    $transaction->trx =  $trx;
                    $transaction->save();
                    notify($to_user, 'BAL_ADD', [
                        'trx' => $trx,
                        'amount' => $pamount,
                        'currency' => $general->cur_text,
                        'post_balance' => getAmount($to_user->balance),
                    ]);
                    $from_user->money_bag -= $pamount;
                    $from_user->save();
                    $notify[] = ['success', $general->cur_sym . $pamount . ' has been deducted from' . $to_user->username . ' moneybag balance'];
                    $transaction1 = new Transaction();
                    $transaction1->user_id = $from_user->id;
                    $transaction1->from_user_id = $to_user->id;
                    $transaction1->amount = $pamount;
                    $transaction1->post_balance = getAmount($from_user->money_bag);
                    $transaction1->charge = 0;
                    $transaction1->trx_type = '-';
                    $transaction1->details = 'Subtract Balance from moneybag';
                    $transaction1->trx =  $trx;
                    $transaction1->save();

                    notify($user, 'BAL_SUB', [
                        'trx' => $trx,
                        'amount' => $pamount,
                        'currency' => $general->cur_text,
                        'post_balance' => getAmount($from_user->money_bag)
                    ]);
                }
            } else {
                $pamount = getAmount($request->amount);
                $general = GeneralSetting::first(['cur_text','cur_sym']);
                $trx = getTrx();
                if ($pamount > $from_user->money_bag) {
                    $notify[] = ['error', $from_user->username . ' has insufficient balance.'];
                    return back()->withNotify($notify);
                } else if($pamount == '0') {
                    $notify[] = ['error', 'Input balance should be more than 0.'];
                    return back()->withNotify($notify);
                } else {
                    $to_user->money_bag += $pamount;
                    $to_user->save();
                    $notify[] = ['success', $general->cur_sym . $pamount . ' has been added to ' . $to_user->username . ' moneybag'];
                    $transaction = new Transaction();
                    $transaction->user_id = $to_user->id;
                    $transaction->from_user_id = $from_user->id;
                    $transaction->amount = $pamount;
                    $transaction->post_balance = getAmount($to_user->balance);
                    $transaction->charge = 0;
                    $transaction->trx_type = '+';
                    $transaction->details = 'Added moneybag topup Via '.$from_user->username;
                    $transaction->trx =  $trx;
                    $transaction->save();
                    notify($to_user, 'BAL_ADD', [
                        'trx' => $trx,
                        'amount' => $pamount,
                        'currency' => $general->cur_text,
                        'post_balance' => getAmount($to_user->balance),
                    ]);
                    $from_user->money_bag -= $pamount;
                    $from_user->save();
                    $notify[] = ['success', $general->cur_sym . $pamount . ' has been deducted from' . $to_user->username . ' moneybag balance'];
                    $transaction1 = new Transaction();
                    $transaction1->user_id = $from_user->id;
                    $transaction1->from_user_id = $to_user->id;
                    $transaction1->amount = $pamount;
                    $transaction1->post_balance = getAmount($from_user->money_bag);
                    $transaction1->charge = 0;
                    $transaction1->trx_type = '-';
                    $transaction1->details = 'Subtract Balance from moneybag';
                    $transaction1->trx =  $trx;
                    $transaction1->save();

                    notify($user, 'BAL_SUB', [
                        'trx' => $trx,
                        'amount' => $pamount,
                        'currency' => $general->cur_text,
                        'post_balance' => getAmount($from_user->money_bag)
                    ]);
                }
            }
        }
        return back()->withNotify($notify);
    }

    public function downlinetopupreport() {
        $data['page_title'] = 'Downline Topup Report';
        $user = Auth::user();
        $data['downlinetopupreport'] = DB::table('transactions')->WHERE('from_user_id', $user->id)->paginate(10);
        return view($this->activeTemplate.'user.downlinetopupreport', $data);
    }

    public function get_sponsor_name(Request $request) {
        $sponsorId = $request->input('sponsor_id');
        $checkSponsorID = DB::table('users')->where('sponsor_id', $sponsorId)->first();
        
        if ($checkSponsorID) {
            $sponsor_name = $checkSponsorID->firstname." ".$checkSponsorID->lastname;
            return response()->json(['success' => true, 'id' => $checkSponsorID->id, 'sponsor_name' => $sponsor_name, 'sponsor_email' => $checkSponsorID->email]);
        }
        return response()->json(['success' => false, 'message' => 'Sponsor ID not found']);
    }
}
